@@ -12,7 +12,7 @@ use File::ShareDir ();
 use Dist::Zilla::Util::CurrentCmd ();
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '2.09'; # VERSION
+our $VERSION = '2.10'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -32,7 +32,7 @@ sub mvp_multivalue_args { qw(
 
 my %plugin_versions = qw(
   Alien                0.023
-  Author::Plicease.*   2.09
+  Author::Plicease.*   2.10
   OurPkgVersion        0.06
   MinimumPerl          1.006
   InstallGuide         1.200006
@@ -169,7 +169,7 @@ sub configure
   
     $self->_my_add_plugin([
       'MetaResources' => {
-        'homepage' => $self->payload->{homepage} || "http://perl.wdlabs.com/$name",
+        'homepage' => $self->payload->{homepage} || "https://metacpan.org/pod/@{[ do { my $foo = $name; $foo =~ s/-/::/g; $foo }]}",
         'bugtracker.web'  => sprintf("https://github.com/%s/%s/issues", $user, $repo),
         'repository.url'  => sprintf("git://github.com/%s/%s.git",      $user, $repo),
         'repository.web'  => sprintf("https://github.com/%s/%s",        $user, $repo),
@@ -320,7 +320,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.09
+version 2.10
 
 =head1 SYNOPSIS
 
@@ -417,7 +417,7 @@ This plugin bundle is mostly equivalent to
  
  [MetaResources]
  bugtracker.web = https://github.com/plicease/My-Dist/issues
- homepage = http://perl.wdlabs.com/My-Dist
+ homepage = https://metacpan.org/pod/My::Dist
  repository.type = git
  repository.url = git://github.com/plicease/My-Dist.git
  repository.web = https://github.com/plicease/My-Dist
